---
template: mainpanel
source_form: markdown
name: Target Types to support
updated: July 2015
reviewed: 18 July 2015
title: Target Types for Pyxie Support
---
### Built in types to be supported

Simple:

* Numbers
* Strings
** Characters - the only extension beyond standard python because we're working in a restricted environment
* Booleans

Harder:

* NULL - Probably constrained **[TBD]**
* LISTS - Probably constrained **[TBD]**
* TUPLES - Probably constrained **[TBD]**
* DICTIONARIES - Probably constrained **[TBD]**
* Objects - classes **[TBD]**

